# Security Policy

## Supported Versions
| Version | Supported          |
| ------- | ------------------ |
| v2.x    | :white_check_mark: |
| v1.x    | :x:                |

## How to Report
Please email security vulnerabilities privately. Do not open public issues for security concerns.

## Response Timeline
- 48 hour acknowledgment
- 7 day patch target
